pyschism.mesh.friction package
==============================

Submodules
----------

pyschism.mesh.friction.drag module
----------------------------------

.. automodule:: pyschism.mesh.friction.drag
   :members:
   :undoc-members:
   :show-inheritance:

pyschism.mesh.friction.fgrid module
-----------------------------------

.. automodule:: pyschism.mesh.friction.fgrid
   :members:
   :undoc-members:
   :show-inheritance:

pyschism.mesh.friction.manning module
-------------------------------------

.. automodule:: pyschism.mesh.friction.manning
   :members:
   :undoc-members:
   :show-inheritance:

pyschism.mesh.friction.rough module
-----------------------------------

.. automodule:: pyschism.mesh.friction.rough
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: pyschism.mesh.friction
   :members:
   :undoc-members:
   :show-inheritance:
